@@ -2,6 +2,8 @@ import geopandas as gpd
 import pandas as pd
 import warnings
 from tqdm import tqdm
+import gzip
+
 
 class DownloadChmap():
     def __init__(self):
@@ -87,7 +89,7 @@ class DownloadChmap():
         elif province_name in ['海南省']:
             if target == province_targetlist[1]:
                 warnings.warn(
-                    message=f"你输入的省为：{province_name}, 属于中国2个特别行政区；输入的 target为: {target} ；将target 转换为: {province_targetlist[2]}")
+                    message=f"你输入的省为：{province_name}, 由于数据问题；输入的 target为: {target} ；将target 转换为: {province_targetlist[2]}")
                 target = '县区'
             return self.download_city(city_name=province_name, target=target)
 
@@ -152,8 +154,40 @@ class DownloadChmap():
         gpd_data = gpd_data.loc[gpd_data['adcode'] == '100000_JD']
         return gpd_data
 
+    @classmethod
+    def download_world(cls, filepath=None):
+        """
+        如果你是在中国, 不方便使用github，可以从我的gitee上下载数据,链接为：
+        https://gitee.com/yuanzhoulvpi/amap_adcode/tree/master/datasets
+        可以看到一个名为world_for_china.gz的文件，点击下载。
+        然后可以添加路径到filepath 参数上：
+        >>> data = DownloadChmap.download_world(filepath="xxxx/xxxx/xxx/world_for_china.gz")
+        >>> data
+        :param filepath:
+        :return:
+        """
+        if filepath is None:
+            msg = """
+            如果你是在中国, 不方便使用github，可以从我的gitee上下载数据,链接为：
+            https://gitee.com/yuanzhoulvpi/amap_adcode/tree/master/datasets
+            可以看到一个名为world_for_china.gz的文件，点击下载。
+            然后可以添加路径到filepath 参数上：
+            >>> data = DownloadChmap.download_world(filepath="xxxx/xxxx/xxx/world_for_china.gz")
+            >>> data
+            """
+            print(msg)
+
+        else:
+            with open(filepath, mode='rb') as fIn:
+                data = gpd.read_file(fIn.read().decode('utf-8'))
+            return data
+
 
 if __name__ == '__main__':
+    # test
     chinamap_engine = DownloadChmap()
-    data = chinamap_engine.download_country(target='县区')
-    # data = chinamap_engine.download_province(province_name='甘肃省', target='县区')
+    # data = chinamap_engine.download_country(target='县区')
+    data = chinamap_engine.download_province(province_name='甘肃省', target='县区')
+    # data = chinamap_engine.download_world()
+    # data = DownloadChmap.download_world(filepath="xxxx/xxxx/xxx/world_for_china.gz")
+    # print(data)
